@@ -7,7 +7,7 @@ import math
 
 
 __all__ = ['ul', 'bounds', 'xy', 'tile', 'parent', 'children', 'bounding_tile']
-__version__ = '0.8.1'
+__version__ = '0.8.2'
 
 Tile = namedtuple('Tile', ['x', 'y', 'z'])
 LngLat = namedtuple('LngLat', ['lng', 'lat'])
@@ -68,6 +68,25 @@ def tile(lng, lat, zoom, truncate=False):
     return Tile(xtile, ytile, zoom)
 
 
+def tiles(west, south, east, north, zooms, truncate=False):
+    if truncate:
+        west, south = truncate_lnglat(west, south)
+        east, north = truncate_lnglat(east, north)
+    if west > east:
+        bbox_west = (-180.0, south, east, north)
+        bbox_east = (west, south, 180.0, north)
+        bboxes = [bbox_west, bbox_east]
+    else:
+        bboxes = [(west, south, east, north)]
+    for w, s, e, n in bboxes:
+        for z in zooms:
+            ll = tile(w, s, z)
+            ur = tile(e, n, z)
+            for i in range(ll.x, min(ur.x + 1, 2**z)):
+                for j in range(ur.y, min(ll.y + 1, 2**z)):
+                    yield Tile(i, j, z)
+
+
 def parent(*tile):
     """Returns the parent of an (x, y, z) tile."""
     if len(tile) == 1:
